#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_SEVEN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_SEVEN_HPP_INCLUDED

#include <boost/simd/constant/include/constants/seven.hpp>

#endif
